@@ -24,6 +24,5 @@
 #define SEARD_ARDUINO_OK           0
 #define SEARD_ARDUINO_BAD_FILE     1
 #define SEARD_ARDUINO_OUT_OF_BOUND 2
-/* #define SEARD_ARDUINO_PIN_MODE_NOT_SET 3 */
+//#define SEARD_ARDUINO_PIN_MODE_NOT_SET 3
 #define SEARD_ARDUINO_WRONG_PIN_MODE 4
-#define SEARD_ARDUINO_WRONG_PIN_TYPE 5
